from setuptools import setup, find_packages

setup(
    name="AQLES",
    version="0.1.0",
    packages=find_packages(),
    install_requires=[
        "pycryptodome"
    ],
    entry_points={
        "console_scripts": [
            "encrypt=cli:main",
        ],
    },
    author="Shayan",
    description="Anti Quantum Leak Encryption System CLI & Library",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://aqles.eldosha.ir/",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.8",
)
